@@ -9,7 +9,7 @@ import (
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
 
-	api "github.com/openshift/elasticsearch-operator/pkg/apis/elasticsearch/v1"
+	api "github.com/openshift/elasticsearch-operator/pkg/apis/logging/v1"
 )
 
 var (
@@ -354,6 +354,44 @@ func TestResourcesCommonResourceAndNodeLimitDefined(t *testing.T) {
 	}
 }
 
+func TestProxyContainerResourcesDefined(t *testing.T) {
+
+	imageName := "openshift/oauth-proxy:1.1"
+	clusterName := "elasticsearch"
+
+	expectedCPU := resource.MustParse("100m")
+	expectedMemory := resource.MustParse("64Mi")
+
+	proxyContainer, err := newProxyContainer(imageName, clusterName)
+	if err != nil {
+		t.Errorf("Failed to populate Proxy container: %v", err)
+	}
+
+	if memoryLimit, ok := proxyContainer.Resources.Limits["memory"]; ok {
+		if memoryLimit.Cmp(expectedMemory) != 0 {
+			t.Errorf("Expected CPU limit %s but got %s", expectedMemory.String(), memoryLimit.String())
+		}
+	} else {
+		t.Errorf("Proxy container is missing CPU limit. Expected limit %s", expectedMemory.String())
+	}
+
+	if cpuRequest, ok := proxyContainer.Resources.Requests["cpu"]; ok {
+		if cpuRequest.Cmp(expectedCPU) != 0 {
+			t.Errorf("Expected CPU request %s but got %s", expectedCPU.String(), cpuRequest.String())
+		}
+	} else {
+		t.Errorf("Proxy container is missing CPU request. Expected request %s", expectedCPU.String())
+	}
+
+	if memoryLimit, ok := proxyContainer.Resources.Limits["memory"]; ok {
+		if memoryLimit.Cmp(expectedMemory) != 0 {
+			t.Errorf("Expected memory limit %s but got %s", expectedMemory.String(), memoryLimit.String())
+		}
+	} else {
+		t.Errorf("Proxy container is missing memory limit. Expected limit %s", expectedMemory.String())
+	}
+}
+
 func TestPodSpecHasTaintTolerations(t *testing.T) {
 
 	expectedTolerations := []v1.Toleration{
@@ -364,13 +402,103 @@ func TestPodSpecHasTaintTolerations(t *testing.T) {
 		},
 	}
 
-	podTemplateSpec := newPodTemplateSpec("test-node-name", "test-cluster-name", "test-namespace-name", api.ElasticsearchNode{}, api.ElasticsearchNodeSpec{}, map[string]string{}, map[api.ElasticsearchNodeRole]bool{})
+	podTemplateSpec := newPodTemplateSpec("test-node-name", "test-cluster-name", "test-namespace-name", api.ElasticsearchNode{}, api.ElasticsearchNodeSpec{}, map[string]string{}, map[api.ElasticsearchNodeRole]bool{}, nil)
 
 	if !reflect.DeepEqual(podTemplateSpec.Spec.Tolerations, expectedTolerations) {
 		t.Errorf("Exp. the tolerations to be %v but was %v", expectedTolerations, podTemplateSpec.Spec.Tolerations)
 	}
 }
 
+// All pods created by Elasticsearch operator needs to be allocated to linux nodes.
+// See LOG-411
+func TestPodNodeSelectors(t *testing.T) {
+
+	var podSpec v1.PodSpec
+
+	// Create podSpecTemplate providing nil/empty node selectors, we expect the PodTemplateSpec.Spec selectors
+	// will contain only the linux allocation selector.
+	podSpec = preparePodTemplateSpecProvidingNodeSelectors(nil).Spec
+
+	if podSpec.NodeSelector == nil {
+		t.Errorf("Exp. the nodeSelector to contains the linux allocation selector but was %T", podSpec.NodeSelector)
+	}
+	if len(podSpec.NodeSelector) != 1 {
+		t.Errorf("Exp. single nodeSelector but %d were found", len(podSpec.NodeSelector))
+	}
+	if podSpec.NodeSelector[OsNodeLabel] != LinuxValue {
+		t.Errorf("Exp. the nodeSelector to contains %s: %s pair", OsNodeLabel, LinuxValue)
+	}
+
+	// Create podSpecTemplate providing some custom node selectors, we expect the PodTemplateSpec.Spec selectors
+	// will add linux node selector.
+	podSpec = preparePodTemplateSpecProvidingNodeSelectors(map[string]string{"foo": "bar", "baz": "foo"}).Spec
+
+	if podSpec.NodeSelector == nil {
+		t.Errorf("Exp. the nodeSelector to contains the linux allocation selector but was %T", podSpec.NodeSelector)
+	}
+	if len(podSpec.NodeSelector) != 3 {
+		t.Errorf("Exp. single nodeSelector but %d were found", len(podSpec.NodeSelector))
+	}
+	if podSpec.NodeSelector[OsNodeLabel] != LinuxValue {
+		t.Errorf("Exp. the nodeSelector to contains %s: %s pair", OsNodeLabel, LinuxValue)
+	}
+
+	// Create podSpecTemplate providing node selector with some custom value, we expect the PodTemplateSpec.Spec selector
+	// will override the node selector to linux one.
+	podSpec = preparePodTemplateSpecProvidingNodeSelectors(map[string]string{OsNodeLabel: "foo"}).Spec
+
+	if podSpec.NodeSelector == nil {
+		t.Errorf("Exp. the nodeSelector to contains the linux allocation selector but was %T", podSpec.NodeSelector)
+	}
+	if len(podSpec.NodeSelector) != 1 {
+		t.Errorf("Exp. single nodeSelector but %d were found", len(podSpec.NodeSelector))
+	}
+	if podSpec.NodeSelector[OsNodeLabel] != LinuxValue {
+		t.Errorf("Exp. the nodeSelector to contains %s: %s pair", OsNodeLabel, LinuxValue)
+	}
+}
+
+func TestPodDiskToleration(t *testing.T) {
+
+	expectedToleration := []v1.Toleration{
+		v1.Toleration{
+			Key:      "node.kubernetes.io/disk-pressure",
+			Operator: v1.TolerationOpExists,
+			Effect:   v1.TaintEffectNoSchedule,
+		},
+	}
+
+	// Create podSpecTemplate providing nil/empty tolerations, we expect the PodTemplateSpec.Spec tolerations
+	// will contain only the disk usage toleration
+	podSpec := preparePodTemplateSpecProvidingNodeSelectors(nil).Spec
+
+	if podSpec.Tolerations == nil {
+		t.Errorf("Exp. the toleration to contains the disk usage toleration but was %T", podSpec.Tolerations)
+	}
+	if len(podSpec.Tolerations) != 1 {
+		t.Errorf("Exp. single toleration but %d were found", len(podSpec.Tolerations))
+	}
+	if !areTolerationsSame(podSpec.Tolerations, expectedToleration) {
+		t.Errorf("Exp. the tolerations to contain %v", expectedToleration)
+	}
+}
+
+// Return a fresh new PodTemplateSpec using provided node selectors.
+// Resulting selectors set always contains also the node selector with value of "linux", see LOG-411
+// This function wraps the call to newPodTempalteSpec in case its signature changes in the future
+// so that keeping unit tests up to date will be easier.
+func preparePodTemplateSpecProvidingNodeSelectors(selectors map[string]string) v1.PodTemplateSpec {
+	return newPodTemplateSpec(
+		"test-node-name",
+		"test-cluster-name",
+		"test-namespace-name",
+		api.ElasticsearchNode{NodeSelector: selectors},
+		api.ElasticsearchNodeSpec{},
+		map[string]string{},
+		map[api.ElasticsearchNodeRole]bool{},
+		nil)
+}
+
 func buildResource(cpuLimit, cpuRequest, memLimit, memRequest resource.Quantity) v1.ResourceRequirements {
 	return v1.ResourceRequirements{
 		Limits: v1.ResourceList{
@@ -424,7 +552,6 @@ func areQuantitiesSame(lhs, rhs *resource.Quantity) bool {
 
 func printResource(resource v1.ResourceRequirements) string {
 	pretty, err := json.MarshalIndent(resource, "", "  ")
-
 	if err != nil {
 		fmt.Printf("Error marshalling to json: %v", pretty)
 	}
